Booster - Heros Devices 0.7.1 documentation

Skip to content
Back to top
View this page

# Booster

From: Sinara Open Hardware Project

Class: `herosdevices.hardware.sinara.booster.Booster`

Driver Quality Index: alpha

Booster 8-channel RF Amplifier.

Bold arguments are mandatory. For more information on the listed arguments refer to the class documentation: `herosdevices.hardware.sinara.booster.Booster` If parameters appear in this list but not in the class definition, please recursively check the linked base classes for the definition of the parameter.

Argument | Type | Default Value | Description
--- | --- | --- | ---
device | <class ‘str’> |  |
port | <class ‘int’> | 5000 |
read_timeout | <class ‘float’> | 1 |

The following JSON strings can be used to start a HERO device representation of `Booster` using BOSS.

    {
        "_id": "my_Booster",
        "classname": "herosdevices.hardware.sinara.booster.Booster",
        "arguments": {
            "device": "<class 'str'>",
            "port": 5000,
            "read_timeout": 1
        }
    }

generated from signature